logger

package
v1.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 16, 2025 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Overview

* Copyright (c) 2025, NVIDIA CORPORATION. All rights reserved. * * Licensed under the Apache License, Version 2.0 (the "License"); * you may not use this file except in compliance with the License. * You may obtain a copy of the License at * * http://www.apache.org/licenses/LICENSE-2.0 * * Unless required by applicable law or agreed to in writing, software * distributed under the License is distributed on an "AS IS" BASIS, * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. * See the License for the specific language governing permissions and * limitations under the License.

Index

Constants

This section is empty.

Variables

Functions

func InitLogger

func InitLogger(config config.Config)

Types

type CustomLogger

type CustomLogger struct {
	// contains filtered or unexported fields
}

CustomLogger is a logger that writes to a channel

func NewCustomLogger

func NewCustomLogger(logChan chan string) *CustomLogger

NewCustomLogger creates a new CustomLogger that writes to the given channel

func (*CustomLogger) Log

func (l *CustomLogger) Log(msg string)

Log writes a log message to the channel

Jump to